@@ -1,5 +1,5 @@
 /****************************************************************************
- * Copyright (c) 1998,1999,2000 Free Software Foundation, Inc.              *
+ * Copyright (c) 1998,1999,2000,2001 Free Software Foundation, Inc.         *
  *                                                                          *
  * Permission is hereby granted, free of charge, to any person obtaining a  *
  * copy of this software and associated documentation files (the            *
@@ -31,41 +31,36 @@
 /*    and: Eric S. Raymond <esr@snark.thyrsus.com>                          */
 /****************************************************************************/
 
-/* $Id: MKterm.h.awk.in,v 1.37 2000/03/12 02:40:07 tom Exp $ */
+/* $Id: MKterm.h.awk.in,v 1.41 2001/12/23 01:04:38 tom Exp $ */
 
 /*
 **	term.h -- Definition of struct term
 */
 
-#ifndef _NCU_TERM_H
-#define _NCU_TERM_H 1
+#ifndef NCURSES_TERM_H_incl
+#define NCURSES_TERM_H_incl 1
 
 #undef  NCURSES_VERSION
-#define NCURSES_VERSION "5.1"
+#define NCURSES_VERSION "5.2"
+
+#include <ncurses_dll.h>
 
 #ifdef __cplusplus
 extern "C" {
 #endif
 
 /* Make this file self-contained by providing defaults for the HAVE_TERMIO[S]_H
- * and BROKEN_LINKER definition (based on the system for which this was
- * configured).
+ * definition (based on the system for which this was configured).
  */
 
 #undef  HAVE_TERMIOS_H
 #define HAVE_TERMIOS_H 1
 
-#undef  HAVE_TERMIO_H
-#define HAVE_TERMIO_H 0
-
 #undef  HAVE_TCGETATTR
 #define HAVE_TCGETATTR 1
 
-#undef  BROKEN_LINKER
-#define BROKEN_LINKER 0
-
 #undef  NCURSES_CONST
-#define NCURSES_CONST 
+#define NCURSES_CONST const
 
 #undef  NCURSES_XNAMES
 #define NCURSES_XNAMES 1
@@ -77,7 +72,7 @@ extern "C" {
 #undef  SET_TTY
 #undef  GET_TTY
 
-/* Assume Posix termio if we have the header and function */
+/* Assume POSIX termio if we have the header and function */
 #if HAVE_TERMIOS_H && HAVE_TCGETATTR
 
 #undef  TERMIOS
@@ -88,7 +83,7 @@ extern "C" {
 
 #else /* !HAVE_TERMIOS_H */
 
-#if HAVE_TERMIO_H
+#if 0 /* HAVE_TERMIO_H */
 
 #undef  TERMIOS
 #define TERMIOS 1
@@ -699,15 +694,15 @@ typedef struct termtype {	/* in-core form of terminfo data */
 
 typedef struct term {		/* describe an actual terminal */
     TERMTYPE	type;		/* terminal type description */
-    short 	Filedes;	/* file description being written to */
+    short	Filedes;	/* file description being written to */
     TTY		Ottyb,		/* original state of the terminal */
 		Nttyb;		/* current state of the terminal */
     int		_baudrate;	/* used to compute padding */
 } TERMINAL;
 
-extern TERMINAL	*cur_term;
+extern NCURSES_EXPORT_VAR(TERMINAL *) cur_term;
 
-#if BROKEN_LINKER
+#if 0 /* BROKEN_LINKER */
 #define boolnames  _nc_boolnames()
 #define boolcodes  _nc_boolcodes()
 #define boolfnames _nc_boolfnames()
@@ -718,70 +713,70 @@ extern TERMINAL	*cur_term;
 #define strcodes   _nc_strcodes()
 #define strfnames  _nc_strfnames()
 
-extern NCURSES_CONST char * const *_nc_boolnames(void);
-extern NCURSES_CONST char * const *_nc_boolcodes(void);
-extern NCURSES_CONST char * const *_nc_boolfnames(void);
-extern NCURSES_CONST char * const *_nc_numnames(void);
-extern NCURSES_CONST char * const *_nc_numcodes(void);
-extern NCURSES_CONST char * const *_nc_numfnames(void);
-extern NCURSES_CONST char * const *_nc_strnames(void);
-extern NCURSES_CONST char * const *_nc_strcodes(void);
-extern NCURSES_CONST char * const *_nc_strfnames(void);
+extern NCURSES_EXPORT(NCURSES_CONST char * const *) _nc_boolnames (void);
+extern NCURSES_EXPORT(NCURSES_CONST char * const *) _nc_boolcodes (void);
+extern NCURSES_EXPORT(NCURSES_CONST char * const *) _nc_boolfnames (void);
+extern NCURSES_EXPORT(NCURSES_CONST char * const *) _nc_numnames (void);
+extern NCURSES_EXPORT(NCURSES_CONST char * const *) _nc_numcodes (void);
+extern NCURSES_EXPORT(NCURSES_CONST char * const *) _nc_numfnames (void);
+extern NCURSES_EXPORT(NCURSES_CONST char * const *) _nc_strnames (void);
+extern NCURSES_EXPORT(NCURSES_CONST char * const *) _nc_strcodes (void);
+extern NCURSES_EXPORT(NCURSES_CONST char * const *) _nc_strfnames (void);
 
 #else
 
-extern NCURSES_CONST char *const boolnames[];
-extern NCURSES_CONST char *const boolcodes[];
-extern NCURSES_CONST char *const boolfnames[];
-extern NCURSES_CONST char *const numnames[];
-extern NCURSES_CONST char *const numcodes[];
-extern NCURSES_CONST char *const numfnames[];
-extern NCURSES_CONST char *const strnames[];
-extern NCURSES_CONST char *const strcodes[];
-extern NCURSES_CONST char *const strfnames[];
+extern NCURSES_EXPORT_VAR(NCURSES_CONST char * const ) boolnames[];
+extern NCURSES_EXPORT_VAR(NCURSES_CONST char * const ) boolcodes[];
+extern NCURSES_EXPORT_VAR(NCURSES_CONST char * const ) boolfnames[];
+extern NCURSES_EXPORT_VAR(NCURSES_CONST char * const ) numnames[];
+extern NCURSES_EXPORT_VAR(NCURSES_CONST char * const ) numcodes[];
+extern NCURSES_EXPORT_VAR(NCURSES_CONST char * const ) numfnames[];
+extern NCURSES_EXPORT_VAR(NCURSES_CONST char * const ) strnames[];
+extern NCURSES_EXPORT_VAR(NCURSES_CONST char * const ) strcodes[];
+extern NCURSES_EXPORT_VAR(NCURSES_CONST char * const ) strfnames[];
 
 #endif
 
 /* internals */
-extern int _nc_set_tty_mode(TTY *buf);
-extern int _nc_get_tty_mode(TTY *buf);
-extern int _nc_read_entry(const char * const, char * const, TERMTYPE *const);
-extern int _nc_read_file_entry(const char *const, TERMTYPE *);
-extern char *_nc_first_name(const char *const);
-extern int _nc_name_match(const char *const, const char *const, const char *const);
-extern int _nc_read_termcap_entry(const char *const, TERMTYPE *const);
-extern const TERMTYPE *_nc_fallback(const char *);
+extern NCURSES_EXPORT(int) _nc_set_tty_mode (TTY *buf);
+extern NCURSES_EXPORT(int) _nc_get_tty_mode (TTY *buf);
+extern NCURSES_EXPORT(int) _nc_read_entry (const char * const, char * const, TERMTYPE *const);
+extern NCURSES_EXPORT(int) _nc_read_file_entry (const char *const, TERMTYPE *);
+extern NCURSES_EXPORT(char *) _nc_first_name (const char *const);
+extern NCURSES_EXPORT(int) _nc_name_match (const char *const, const char *const, const char *const);
+extern NCURSES_EXPORT(int) _nc_read_termcap_entry (const char *const, TERMTYPE *const);
+extern NCURSES_EXPORT(const TERMTYPE *) _nc_fallback (const char *);
 
 /* entry points */
-extern TERMINAL *set_curterm(TERMINAL *);
-extern int del_curterm(TERMINAL *);
+extern NCURSES_EXPORT(TERMINAL *) set_curterm (TERMINAL *);
+extern NCURSES_EXPORT(int) del_curterm (TERMINAL *);
 
 /* miscellaneous entry points */
-extern int restartterm(NCURSES_CONST char *, int, int *);
-extern int setupterm(NCURSES_CONST char *,int,int *);
+extern NCURSES_EXPORT(int) restartterm (NCURSES_CONST char *, int, int *);
+extern NCURSES_EXPORT(int) setupterm (NCURSES_CONST char *,int,int *);
 
 /* terminfo entry points, also declared in curses.h */
 #if !defined(__NCURSES_H)
-extern char *tigetstr(NCURSES_CONST char *);
-extern char *tparm(NCURSES_CONST char *, ...);
-extern char ttytype[];
-extern int putp(const char *);
-extern int tigetflag(NCURSES_CONST char *);
-extern int tigetnum(NCURSES_CONST char *);
+extern NCURSES_EXPORT(char *) tigetstr (NCURSES_CONST char *);
+extern NCURSES_EXPORT(char *) tparm (NCURSES_CONST char *, ...);
+extern NCURSES_EXPORT_VAR(char) ttytype[];
+extern NCURSES_EXPORT(int) putp (const char *);
+extern NCURSES_EXPORT(int) tigetflag (NCURSES_CONST char *);
+extern NCURSES_EXPORT(int) tigetnum (NCURSES_CONST char *);
 #endif /* __NCURSES_H */
 
 /* termcap database emulation (XPG4 uses const only for 2nd param of tgetent) */
-#if !defined(_NCU_TERMCAP_H)
-extern char *tgetstr(NCURSES_CONST char *, char **);
-extern char *tgoto(const char *, int, int);
-extern int tgetent(char *, const char *);
-extern int tgetflag(NCURSES_CONST char *);
-extern int tgetnum(NCURSES_CONST char *);
-extern int tputs(const char *, int, int (*)(int));
-#endif /* _NCU_TERMCAP_H */
+#if !defined(NCURSES_TERMCAP_H_incl)
+extern NCURSES_EXPORT(char *) tgetstr (NCURSES_CONST char *, char **);
+extern NCURSES_EXPORT(char *) tgoto (const char *, int, int);
+extern NCURSES_EXPORT(int) tgetent (char *, const char *);
+extern NCURSES_EXPORT(int) tgetflag (NCURSES_CONST char *);
+extern NCURSES_EXPORT(int) tgetnum (NCURSES_CONST char *);
+extern NCURSES_EXPORT(int) tputs (const char *, int, int (*)(int));
+#endif /* NCURSES_TERMCAP_H_incl */
 
 #ifdef __cplusplus
 }
 #endif
 
-#endif /* _NCU_TERM_H */
+#endif /* NCURSES_TERM_H_incl */
